// This source code is a part of Project Violet.
// Copyright (C) 2020-2022. violet-team. Licensed under the Apache-2.0 License.

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:violet/locale/locale.dart';
import 'package:violet/other/dialogs.dart';
import 'package:violet/settings/settings.dart';

class SearchPageModifyPage extends StatefulWidget {
  final int curPage;
  final int maxPage;

  const SearchPageModifyPage({this.curPage, this.maxPage});

  @override
  _SearchPageModifyPageState createState() => _SearchPageModifyPageState();
}

class _SearchPageModifyPageState extends State<SearchPageModifyPage> {
  TextEditingController _pageController;

  @override
  void initState() {
    super.initState();

    _pageController = TextEditingController(text: widget.curPage.toString());
  }

  @override
  Widget build(BuildContext context) {
    return AlertDialog(
      title: Text('Item Jump'),
      contentPadding: EdgeInsets.fromLTRB(12, 8, 12, 8),
      content: Column(
        mainAxisSize: MainAxisSize.min,
        children: <Widget>[
          Row(children: [
            Text('${Translations.of(context).trans('position')}: '),
            Expanded(
              child: TextField(
                controller: _pageController,
                keyboardType: TextInputType.number,
                inputFormatters: <TextInputFormatter>[
                  FilteringTextInputFormatter.digitsOnly
                ], // Only numbers can be entered
              ),
            ),
            Text(' / ${widget.maxPage}'),
          ]),
          Container(
            height: 16,
          ),
          Row(
            children: <Widget>[
              const Spacer(),
              ElevatedButton(
                style: ElevatedButton.styleFrom(
                  primary: Settings.majorColor,
                ),
                child: Text(Translations.of(context).trans('ok')),
                onPressed: () async {
                  if (_pageController.text == "") {
                    Navigator.pop(context, [
                      1,
                      0,
                    ]);
                    return;
                  }
                  if (int.parse(_pageController.text.trim()) >=
                      widget.maxPage) {
                    await showOkDialog(
                        context,
                        Translations.of(context)
                            .trans('setlowerthanmaxitemposition'));
                    return;
                  }
                  Navigator.pop(context, [
                    1,
                    int.parse(_pageController.text),
                  ]);
                },
              ),
              const SizedBox(width: 8),
              ElevatedButton(
                style: ElevatedButton.styleFrom(
                  primary: Settings.majorColor,
                ),
                child: Text(Translations.of(context).trans('cancel')),
                onPressed: () {
                  Navigator.pop(context, [0]);
                },
              ),
            ],
          )
        ],
      ),
    );
  }
}
